%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Application Note AN006
% System parameters for the 'central PV inverter' system
% Copyright imperix ltd, 2020
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SYSTEM PARAMETERS
fsw = 16e3;                 % Switching frequency [kHz]
CTRLPERIOD = 1/fsw;         % Closed-loop control period [s]
MPPTPERIOD = 1/200;         % MPP tracking interval [s]

Ts = 1.5*CTRLPERIOD;        % Total control delay [s]

Pg_n = 2000;                % Nominal system power [W]
fg_n = 50;                  % Nominal grid frequency [Hz]
wg_n = fg_n*2*pi;           % Nominal grid pulsation [rad/s]
Vg_n = 230;                 % Nominal grid voltage (rms) [V]
Vg_n_pk = Vg_n*sqrt(2);     % Nominal grid voltage (peak) [V]
Ig_n = Pg_n/Vg_n;           % Nominal grid current (rms) [A]
Ig_n_pk = Ig_n*sqrt(2);     % Nominal grid current (peak) [A]

Lb = 2.5e-3;                % Boost-side inductor value [H]
Rb = 22e-3;                 % Series equivalent resistrance of Lb [ohm]
Lg = 2.5e-3;                % Grid-side inductor value [H]
Rg = 22e-3;                 % Series equivalent resistrance of Lg [ohm]
Ls = 30e-6;                % Grid voltage source inductance at PCC [H]
Cdc = 4*130e-6;             % Total DC bus capacitance (4 modules) [F]

Isc = 50;                   % PV panel's short-circuit current [A]
Voc = 300;                  % PV panel's open-circuit voltage [V]

%% SETPOINTS
Vdc_ref = 700;              % DC bus voltage reference setpoint [V]

%% INITIAL VALUES
Vdc0 = Vdc_ref;             % Initial DC bus voltage [V]           


%% BOOST CURRENT CONTROLLER PARAMETERS
% Optimum magnitude criterion
K1 = 1/Rb;
T1 = Lb/Rb;

Tn1 = T1;
Ti1 = 2*K1*Ts;

Kp1 = Tn1/Ti1;
Ki1 = 1/Ti1;
Kbc1 = Ki1/Kp1;

%% CASCADED VOLTAGE CONTROLLER
T2 = Cdc;
Ts2 = 13*CTRLPERIOD;

Tn2 = 4*Ts2;
Ti2 = 8*Ts2^2/T2;

Kp2 = Tn2/Ti2;
Ki2 = 1/Ti2;
Kbc2 = Ki2/Kp2;

%% GRID CURRENT CONTROLLER (DQ)
% Optimum magnitude criterion
Ts3 = Ts;

K3 = 1/Rg;
T3 = Lg/Rg;

Tn3 = T3;
Ti3 = 2*K3*Ts3;

Kp3 = Tn3/Ti3;
Ki3 = 1/Ti3;
Kbc3 = Ki3/Kp3;

